@@ -2,24 +2,20 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
-from django.db.models import OuterRef
-from django.db.models import Subquery
-from django.db.models import TextField
-from django.db.models.functions import Cast
-from morango.models import TransferSession
 from rest_framework import serializers
 from rest_framework.validators import UniqueTogetherValidator
 
+from .errors import IncompatibleDeviceSettingError
+from .errors import InvalidCollectionHierarchy
+from .errors import InvalidMembershipError
 from .models import Classroom
 from .models import Facility
 from .models import FacilityDataset
 from .models import FacilityUser
 from .models import LearnerGroup
-from .models import AdHocGroup
 from .models import Membership
 from .models import Role
 from kolibri.core import error_constants
-from kolibri.core.device.utils import allow_guest_access
 
 
 class RoleSerializer(serializers.ModelSerializer):
@@ -72,10 +68,14 @@ class MembershipSerializer(serializers.ModelSerializer):
         model = Membership
         fields = ("id", "collection", "user")
 
+    def save(self, **kwargs):
+        try:
+            return super(MembershipSerializer, self).save(**kwargs)
+        except InvalidMembershipError as e:
+            raise serializers.ValidationError(str(e))
+
 
 class FacilityDatasetSerializer(serializers.ModelSerializer):
-    allow_guest_access = serializers.SerializerMethodField()
-
     class Meta:
         model = FacilityDataset
         fields = (
@@ -89,50 +89,46 @@ class FacilityDatasetSerializer(serializers.ModelSerializer):
             "show_download_button_in_learn",
             "description",
             "location",
-            "allow_guest_access",
             "registered",
+            "preset",
         )
 
-    def get_allow_guest_access(self, instance):
-        return allow_guest_access()
+    def save(self, **kwargs):
+        try:
+            return super(FacilityDatasetSerializer, self).save(**kwargs)
+        except IncompatibleDeviceSettingError as e:
+            raise serializers.ValidationError(str(e))
 
 
 class FacilitySerializer(serializers.ModelSerializer):
-    dataset = FacilityDatasetSerializer(read_only=True)
-    default = serializers.SerializerMethodField()
-    last_synced = serializers.SerializerMethodField()
-
     class Meta:
         model = Facility
-        extra_kwargs = {"id": {"read_only": True}, "dataset": {"read_only": True}}
-        fields = ("id", "name", "dataset", "default", "last_synced")
-
-    def get_default(self, instance):
-        return instance == Facility.get_default_facility()
-
-    def get_last_synced(self, instance):
-
-        # when facilities are synced, the dataset_id is used as the filter
-        last_synced = (
-            TransferSession.objects.filter(filter=OuterRef("casted_dataset_id"))
-            .order_by("-last_activity_timestamp")
-            .values("last_activity_timestamp")[:1]
-        )
-
-        # get last synced date
-        last_synced_date = (
-            Facility.objects.filter(id=instance.id)
-            .annotate(casted_dataset_id=Cast("dataset_id", TextField()))
-            .annotate(last_synced=Subquery(last_synced))
-            .values_list("last_synced", flat=True)
-        )
-        return last_synced_date[0]
+        extra_kwargs = {"id": {"read_only": True}}
+        fields = ("id", "name")
 
 
 class PublicFacilitySerializer(serializers.ModelSerializer):
+    learner_can_login_with_no_password = serializers.SerializerMethodField()
+
+    def get_learner_can_login_with_no_password(self, instance):
+        return instance.dataset.learner_can_login_with_no_password
+
     class Meta:
         model = Facility
-        fields = ("id", "dataset", "name")
+        fields = ("id", "dataset", "name", "learner_can_login_with_no_password")
+
+
+class PublicFacilityUserSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = FacilityUser
+        fields = (
+            "id",
+            "username",
+            "full_name",
+            "facility",
+            "roles",
+            "is_superuser",
+        )
 
 
 class ClassroomSerializer(serializers.ModelSerializer):
@@ -147,6 +143,12 @@ class ClassroomSerializer(serializers.ModelSerializer):
             )
         ]
 
+    def save(self, **kwargs):
+        try:
+            return super(ClassroomSerializer, self).save(**kwargs)
+        except InvalidCollectionHierarchy as e:
+            raise serializers.ValidationError(str(e))
+
 
 class LearnerGroupSerializer(serializers.ModelSerializer):
     class Meta:
@@ -159,14 +161,8 @@ class LearnerGroupSerializer(serializers.ModelSerializer):
             )
         ]
 
-
-class AdHocGroupSerializer(serializers.ModelSerializer):
-
-    user_ids = serializers.SerializerMethodField()
-
-    def get_user_ids(self, group):
-        return [str(user_id["id"]) for user_id in group.get_members().values("id")]
-
-    class Meta:
-        model = AdHocGroup
-        fields = ("id", "name", "parent", "user_ids")
+    def save(self, **kwargs):
+        try:
+            return super(LearnerGroupSerializer, self).save(**kwargs)
+        except InvalidCollectionHierarchy as e:
+            raise serializers.ValidationError(str(e))
