@@ -5,11 +5,19 @@ from __future__ import unicode_literals
 import base64
 import collections
 import sys
+import time
+import uuid
+from datetime import datetime
 from importlib import import_module
 
 import factory
 from django.conf import settings
 from django.core.urlresolvers import reverse
+from django.utils import timezone
+from morango.constants import transfer_stages
+from morango.constants import transfer_statuses
+from morango.models import SyncSession
+from morango.models import TransferSession
 from rest_framework import status
 from rest_framework.test import APITestCase as BaseTestCase
 
@@ -430,6 +438,31 @@ class FacilityAPITestCase(APITestCase):
         cls.facility2 = FacilityFactory.create()
         cls.user1 = FacilityUserFactory.create(facility=cls.facility1)
         cls.user2 = FacilityUserFactory.create(facility=cls.facility2)
+        cls.date_completed_transfer_session = datetime(2022, 6, 30, tzinfo=timezone.utc)
+        cls.date_failed_transfer_session = datetime(2022, 6, 14, tzinfo=timezone.utc)
+        cls.sync_session = SyncSession.objects.create(
+            id=uuid.uuid4().hex,
+            profile="facilitydata",
+            last_activity_timestamp=cls.date_completed_transfer_session,
+        )
+        cls.completed_push_transfer_session = TransferSession.objects.create(
+            id=uuid.uuid4().hex,
+            sync_session_id=cls.sync_session.id,
+            filter=cls.facility1.dataset_id,
+            push=True,
+            active=False,
+            transfer_stage=transfer_stages.CLEANUP,
+            transfer_stage_status=transfer_statuses.COMPLETED,
+            last_activity_timestamp=cls.date_completed_transfer_session,
+        )
+        cls.failed_transfer_session = TransferSession.objects.create(
+            id=uuid.uuid4().hex,
+            sync_session_id=cls.sync_session.id,
+            filter=cls.facility1.dataset_id,
+            push=True,
+            transfer_stage_status=transfer_statuses.ERRORED,
+            last_activity_timestamp=cls.date_failed_transfer_session,
+        )
 
     def test_sanity(self):
         self.assertTrue(
@@ -455,6 +488,35 @@ class FacilityAPITestCase(APITestCase):
             {"name": self.facility1.name}, dict(response.data)
         )
 
+    def test_facility_user_can_get_last_successful_sync(self):
+        self.client.login(
+            username=self.user1.username,
+            password=DUMMY_PASSWORD,
+            facility=self.facility1,
+        )
+        response = self.client.get(
+            reverse("kolibri:core:facility-detail", kwargs={"pk": self.facility1.pk}),
+            format="json",
+        )
+        self.assertEqual(
+            response.data["last_successful_sync"],
+            self.date_completed_transfer_session,
+        )
+
+    def test_facility_user_can_get_last_failed_sync(self):
+        self.client.login(
+            username=self.user1.username,
+            password=DUMMY_PASSWORD,
+            facility=self.facility1,
+        )
+        response = self.client.get(
+            reverse("kolibri:core:facility-detail", kwargs={"pk": self.facility1.pk}),
+            format="json",
+        )
+        self.assertEqual(
+            response.data["last_failed_sync"], self.date_failed_transfer_session
+        )
+
     def test_device_admin_can_create_facility(self):
         new_facility_name = "New Facility"
         self.client.login(
@@ -1043,6 +1105,7 @@ class LoginLogoutTestCase(APITestCase):
             format="json",
         )
         expire_date = self.client.session.get_expiry_date()
+        time.sleep(0.01)
         self.client.get(
             reverse("kolibri:core:session-detail", kwargs={"pk": "current"})
         )
