@@ -18,6 +18,7 @@ from django.http.request import HttpRequest
 from django.utils.cache import patch_response_headers
 from django.utils.decorators import method_decorator
 from django.utils.translation import ugettext as _
+from django.views.decorators.cache import cache_page
 from django.views.decorators.http import etag
 from django_filters.rest_framework import BaseInFilter
 from django_filters.rest_framework import BooleanFilter
@@ -29,6 +30,7 @@ from django_filters.rest_framework import NumberFilter
 from django_filters.rest_framework import UUIDFilter
 from le_utils.constants import content_kinds
 from le_utils.constants import languages
+from rest_framework import filters
 from rest_framework import mixins
 from rest_framework import status
 from rest_framework import viewsets
@@ -75,7 +77,6 @@ from kolibri.core.utils.pagination import ValuesViewsetCursorPagination
 from kolibri.core.utils.pagination import ValuesViewsetLimitOffsetPagination
 from kolibri.core.utils.pagination import ValuesViewsetPageNumberPagination
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -610,6 +611,7 @@ def get_resume_queryset(request, queryset):
         .exclude(progress=1)
         .values_list("content_id", flat=True)
     )
+
     return queryset.filter(content_id__in=content_ids)
 
 
@@ -1382,10 +1384,28 @@ class UserContentNodeViewset(BaseContentNodeMixin, BaseValuesViewset, ListModelM
     A content node viewset for filtering on user specific fields.
     """
 
-    filter_backends = (DjangoFilterBackend,)
+    filter_backends = (DjangoFilterBackend, filters.OrderingFilter)
+    ordering_fields = ["last_interacted"]
+    ordering = ("lft", "id")
     filter_class = UserContentNodeFilter
     pagination_class = OptionalPagination
 
+    def get_queryset(self):
+        user = self.request.user
+
+        queryset = models.ContentNode.objects.filter(available=True)
+        if not user.is_facility_user:
+            user = None
+
+        queryset = queryset.annotate(
+            last_interacted=Subquery(
+                ContentSummaryLog.objects.filter(
+                    content_id=OuterRef("content_id"), user=user
+                ).values_list("end_timestamp")[:1]
+            )
+        )
+        return queryset
+
 
 def mean(data):
     n = 0
@@ -1401,7 +1421,9 @@ def mean(data):
 class ContentNodeProgressViewset(
     TreeQueryMixin, viewsets.GenericViewSet, ListModelMixin
 ):
-    filter_backends = (DjangoFilterBackend,)
+    filter_backends = (DjangoFilterBackend, filters.OrderingFilter)
+    ordering_fields = ["last_interacted"]
+    ordering = ("lft", "id")
     filter_class = UserContentNodeFilter
     # Use same pagination class as ContentNodeViewset so we can
     # return identically paginated responses.
@@ -1412,7 +1434,20 @@ class ContentNodeProgressViewset(
     pagination_class = OptionalPagination
 
     def get_queryset(self):
-        return models.ContentNode.objects.filter(available=True)
+        user = self.request.user
+
+        queryset = models.ContentNode.objects.filter(available=True)
+        if not user.is_facility_user:
+            user = None
+
+        queryset = queryset.annotate(
+            last_interacted=Subquery(
+                ContentSummaryLog.objects.filter(
+                    content_id=OuterRef("content_id"), user=user
+                ).values_list("end_timestamp")[:1]
+            )
+        )
+        return queryset
 
     def generate_response(self, request, queryset):
         if request.user.is_anonymous():
@@ -1448,6 +1483,7 @@ class FileViewset(viewsets.ReadOnlyModelViewSet):
         return models.File.objects.all()
 
 
+@method_decorator(cache_page(60 * 5), name="dispatch")
 class RemoteChannelViewSet(viewsets.ViewSet):
     permission_classes = (CanManageContent,)
 
@@ -1530,9 +1566,10 @@ class RemoteChannelViewSet(viewsets.ViewSet):
         baseurl = request.GET.get("baseurl", None)
         keyword = request.GET.get("keyword", None)
         language = request.GET.get("language", None)
+        token = request.GET.get("token", None)
         try:
             channels = self._make_channel_endpoint_request(
-                baseurl=baseurl, keyword=keyword, language=language
+                identifier=token, baseurl=baseurl, keyword=keyword, language=language
             )
         except requests.exceptions.ConnectionError:
             return Response(
@@ -1569,19 +1606,3 @@ class RemoteChannelViewSet(viewsets.ViewSet):
                 return Response({"status": "online"})
         except requests.ConnectionError:
             return Response({"status": "offline"})
-
-    @detail_route(methods=["get"])
-    def retrieve_list(self, request, pk=None):
-        baseurl = request.GET.get("baseurl", None)
-        keyword = request.GET.get("keyword", None)
-        language = request.GET.get("language", None)
-        try:
-            return Response(
-                self._make_channel_endpoint_request(
-                    identifier=pk, baseurl=baseurl, keyword=keyword, language=language
-                )
-            )
-        except requests.exceptions.ConnectionError:
-            return Response(
-                {"status": "offline"}, status=status.HTTP_503_SERVICE_UNAVAILABLE
-            )
