@@ -1,13 +1,13 @@
 import logging
 import os
 
-from le_utils.constants import content_kinds
+from django.core.management.base import CommandError
 
 from ...utils import paths
 from ...utils import transfer
 from kolibri.core.content.errors import InvalidStorageFilenameError
-from kolibri.core.content.utils.import_export_content import calculate_files_to_transfer
-from kolibri.core.content.utils.import_export_content import get_nodes_to_transfer
+from kolibri.core.content.utils.import_export_content import get_import_export_data
+from kolibri.core.content.utils.paths import get_content_file_name
 from kolibri.core.tasks.management.commands.base import AsyncCommand
 from kolibri.core.tasks.utils import get_current_job
 
@@ -63,6 +63,8 @@ class Command(AsyncCommand):
             job.save_meta()
 
     def handle_async(self, *args, **options):
+        if paths.using_remote_storage():
+            raise CommandError("Cannot export files when using remote file storage")
         channel_id = options["channel_id"]
         data_dir = os.path.realpath(options["destination"])
         node_ids = options["node_ids"]
@@ -71,20 +73,11 @@ class Command(AsyncCommand):
             "Exporting content for channel id {} to {}".format(channel_id, data_dir)
         )
 
-        nodes_for_transfer = get_nodes_to_transfer(
-            channel_id, node_ids, exclude_node_ids, True
-        )
-
-        total_resource_count = (
-            nodes_for_transfer.exclude(kind=content_kinds.TOPIC)
-            .values("content_id")
-            .distinct()
-            .count()
-        )
-
-        (files, total_bytes_to_transfer) = calculate_files_to_transfer(
-            nodes_for_transfer, True
-        )
+        (
+            total_resource_count,
+            files,
+            total_bytes_to_transfer,
+        ) = get_import_export_data(channel_id, node_ids, exclude_node_ids, True)
 
         self.update_job_metadata(total_bytes_to_transfer, total_resource_count)
 
@@ -110,19 +103,19 @@ class Command(AsyncCommand):
                 self.cancel()
 
     def export_file(self, f, data_dir, overall_progress_update):
-        filename = f.get_filename()
+        filename = get_content_file_name(f)
 
         try:
             srcpath = paths.get_content_storage_file_path(filename)
             dest = paths.get_content_storage_file_path(filename, datafolder=data_dir)
         except InvalidStorageFilenameError:
             # If any files have an invalid storage file name, don't export them.
-            overall_progress_update(f.file_size)
+            overall_progress_update(f["file_size"])
             return
 
         # if the file already exists, add its size to our overall progress, and skip
-        if os.path.isfile(dest) and os.path.getsize(dest) == f.file_size:
-            overall_progress_update(f.file_size)
+        if os.path.isfile(dest) and os.path.getsize(dest) == f["file_size"]:
+            overall_progress_update(f["file_size"])
             return
 
         copy = transfer.FileCopy(srcpath, dest, cancel_check=self.is_cancelled)
