@@ -7,6 +7,13 @@ from itertools import chain
 from django.test import TestCase
 from le_utils.constants import content_kinds
 from le_utils.constants import format_presets
+from le_utils.constants.labels.accessibility_categories import (
+    ACCESSIBILITYCATEGORIESLIST,
+)
+from le_utils.constants.labels.learning_activities import LEARNINGACTIVITIESLIST
+from le_utils.constants.labels.levels import LEVELSLIST
+from le_utils.constants.labels.needs import NEEDSLIST
+from le_utils.constants.labels.subjects import SUBJECTSLIST
 from mock import patch
 from sqlalchemy import create_engine
 
@@ -35,6 +42,10 @@ def uuid4_hex():
     return uuid.uuid4().hex
 
 
+def choices(sequence, k):
+    return [random.choice(sequence) for _ in range(0, k)]
+
+
 class ChannelBuilder(object):
     """
     This class is purely to generate all the relevant data for a single
@@ -52,20 +63,24 @@ class ChannelBuilder(object):
         "root_node",
     )
 
-    def __init__(self, levels=3):
+    def __init__(self, levels=3, num_children=5):
         self.levels = levels
+        self.num_children = num_children
 
         self.modified = set()
 
         try:
             self.load_data()
         except KeyError:
-            print("key error {}".format(self.levels))
             self.generate_new_tree()
             self.save_data()
 
         self.generate_nodes_from_root_node()
 
+    @property
+    def cache_key(self):
+        return "{}_{}".format(self.levels, self.num_children)
+
     def generate_new_tree(self):
         self.channel = self.channel_data()
         self.files = {}
@@ -82,10 +97,18 @@ class ChannelBuilder(object):
             )
 
     def load_data(self):
-        data = copy.deepcopy(self.__TREE_CACHE[self.levels])
+        try:
+            data = copy.deepcopy(self.__TREE_CACHE[self.cache_key])
 
-        for key in self.tree_keys:
-            setattr(self, key, data[key])
+            for key in self.tree_keys:
+                setattr(self, key, data[key])
+        except KeyError:
+            print(
+                "No tree cache found for {} levels and {} children per level".format(
+                    self.levels, self.num_children
+                )
+            )
+            raise
 
     def save_data(self):
         data = {}
@@ -93,7 +116,7 @@ class ChannelBuilder(object):
         for key in self.tree_keys:
             data[key] = getattr(self, key)
 
-        self.__TREE_CACHE[self.levels] = copy.deepcopy(data)
+        self.__TREE_CACHE[self.cache_key] = copy.deepcopy(data)
 
     def generate_nodes_from_root_node(self):
         self._django_nodes = ContentNode.objects.build_tree_nodes(self.root_node)
@@ -297,7 +320,7 @@ class ChannelBuilder(object):
 
     def recurse_and_generate(self, parent_id, levels):
         children = []
-        for i in range(0, 5):
+        for i in range(0, self.num_children):
             if levels == 0:
                 node = self.generate_leaf(parent_id)
             else:
@@ -388,6 +411,8 @@ class ChannelBuilder(object):
     def contentnode_data(
         self, node_id=None, content_id=None, parent_id=None, kind=None, root=False
     ):
+        # First kind in choices is Topic, so exclude it here.
+        kind = kind or random.choice(content_kinds.choices[1:])[0]
         return {
             "options": "{}",
             "content_id": content_id or uuid4_hex(),
@@ -401,10 +426,18 @@ class ChannelBuilder(object):
             "author": "",
             "title": "Test",
             "parent_id": None if root else parent_id or uuid4_hex(),
-            # First kind in choices is Topic, so exclude it here.
-            "kind": kind or random.choice(content_kinds.choices[1:])[0],
+            "kind": kind,
             "coach_content": False,
             "available": False,
+            "learning_activities": ",".join(
+                set(choices(LEARNINGACTIVITIESLIST, k=random.randint(1, 3)))
+            ),
+            "accessibility_labels": ",".join(
+                set(choices(ACCESSIBILITYCATEGORIESLIST, k=random.randint(1, 3)))
+            ),
+            "grade_levels": ",".join(set(choices(LEVELSLIST, k=random.randint(1, 2)))),
+            "categories": ",".join(set(choices(SUBJECTSLIST, k=random.randint(1, 10)))),
+            "learner_needs": ",".join(set(choices(NEEDSLIST, k=random.randint(1, 5)))),
         }
 
 
