@@ -25,7 +25,8 @@ class VersionUpgrade(object):
         # If None - should be applied to all.
         self.OLD_VERSION = old_version
         try:
-            assert self._old
+            if not self._old:
+                raise AssertionError
         except AssertionError:
             raise TypeError(
                 "Unparseable semver version or range passed to upgrade object for old_version"
@@ -35,7 +36,8 @@ class VersionUpgrade(object):
         # If None - should be applied to all.
         self.NEW_VERSION = new_version
         try:
-            assert self._new
+            if not self._new:
+                raise AssertionError
         except AssertionError:
             raise TypeError(
                 "Unparseable semver version or range passed to upgrade object for new_version"
@@ -145,7 +147,10 @@ def run_upgrades(old_version, new_version, app_configs=None):
             and matches_version(new_version, upgrade.NEW_VERSION)
         )
 
-    for version_upgrade in sorted(
-        filter(filter_upgrade, get_upgrades(app_configs=app_configs))
-    ):
-        version_upgrade()
+    # Only run upgrades if we had a previous version, otherwise
+    # we're just upgrading from a blank slate, so no need to run anything
+    if old_version:
+        for version_upgrade in sorted(
+            filter(filter_upgrade, get_upgrades(app_configs=app_configs))
+        ):
+            version_upgrade()
