@@ -392,6 +392,11 @@ def autoremove_unavailable_plugins():
     configured by the user or some other kind of hard dependency that should
     make execution stop if not loadable.
     """
+    from kolibri.plugins.registry import is_initialized
+
+    if is_initialized():
+        # TODO: Turn this into a Runtime error
+        logger.warning("Attempted to updated plugins when registry is initialized")
     changed = False
     # Iterate over a copy of the set so that it is not modified during the loop
     for module_path in config["INSTALLED_PLUGINS"].copy():
@@ -415,6 +420,11 @@ def enable_new_default_plugins():
     default plugins that have been explicitly disabled by a user,
     in versions prior to the implementation of a plugin blacklist.
     """
+    from kolibri.plugins.registry import is_initialized
+
+    if is_initialized():
+        # TODO: Turn this into a Runtime error
+        logger.warning("Attempted to updated plugins when registry is initialized")
     changed = False
     for module_path in DEFAULT_PLUGINS:
         if module_path not in config["INSTALLED_PLUGINS"]:
