@@ -13,73 +13,64 @@ Here's how version numbers are generated:
    to decide the version of Kolibri as a string. This is especially something
    that PyPi and setuptools use.
 
- * ``kolibri.VERSION`` is a tuple containing version information, it's set in
-   ``kolibri/__init__.py`` is automatically suffixed in pre-releases by a
-   number of rules defined below. For a final release (not a pre-release),
-   it will be used exactly as it appears.
+ * ``kolibri.VERSION`` is a tuple containing major, minor, and patch version information,
+   it's set in ``kolibri/__init__.py``
 
  * ``kolibri/VERSION`` is a file containing the exact version of Kolibri for a
-   distributed environment (pre-releases only!)
+   distributed environment - when it exists, as long as its major, minor, and patch
+   versions are compatible with ``kolibri.VERSION`` then it is used as the version.
+   If these versions do not match, an AssertionError will be thrown.
 
  * ``git describe --tags`` is a command run to fetch tag information from a git
    checkout with the Kolibri code. The information is used to validate the
-   major components of ``kolibri.VERSION`` and to suffix the final version of
-   prereleases. This information is stored permanently in ``kolibri/VERSION``
-   before shipping a pre-release by calling ``make writeversion`` during
-   ``make dist`` etc.
+   major components of ``kolibri.VERSION`` and to add a suffix (if needed).
+   This information is stored permanently in ``kolibri/VERSION`` before shipping
+   any built asset by calling ``make writeversion`` during ``make dist`` etc.
 
 
-Confused? Here's a table:
+This table shows examples of kolibri.VERSION and git data used to generate a specific version:
 
 
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
-| Release type | ``kolibri.VERSION`` | ``kolibri/VERSION`` | Git data                  | Examples                            |
-+==============+=====================+=====================+===========================+=====================================+
-| Final        | Canonical, only     | N/A                 | N/A                       | 0.1.0, 0.2.2,                       |
-|              | information used    |                     |                           | 0.2.post1                           |
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
-| dev release  | (1, 2, 3, 'alpha',  | Fallback            | timestamp of latest       | 1.2.3.dev0+git.123.f1234567         |
-| (alpha0)     | 0), 0th alpha = a   |                     | commit + hash             |                                     |
-|              | dev release! Never  |                     |                           |                                     |
-|              | used as a canonical |                     |                           |                                     |
-|              |                     |                     |                           |                                     |
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
-| alpha1+      | (1, 2, 3, 'alpha',  | Fallback            | ``git describe --tags``   | Clean head:                         |
-|              | 1)                  |                     |                           | 1.2.3a1,                            |
-|              |                     |                     |                           | 4 changes                           |
-|              |                     |                     |                           | since tag:                          |
-|              |                     |                     |                           | 1.2.3a1.dev0+git.4.f1234567         |
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
-| beta1+       | (1, 2, 3, 'alpha',  | Fallback            | ``git describe --tags``   | Clean head:                         |
-|              | 1)                  |                     |                           | 1.2.3b1,                            |
-|              |                     |                     |                           | 5 changes                           |
-|              |                     |                     |                           | since tag:                          |
-|              |                     |                     |                           | 1.2.3b1.dev0+git.5.f1234567         |
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
-| rc1+         | (1, 2, 3, 'alpha',  | Fallback            | ``git describe --tags``   | Clean head:                         |
-| (release     | 1)                  |                     |                           | 1.2.3rc1,                           |
-| candidate)   |                     |                     |                           | Changes                             |
-|              |                     |                     |                           | since tag:                          |
-|              |                     |                     |                           | 1.2.3rc1.dev0+git.f1234567          |
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
-| beta0, rc0,  | DO NOT USE          | Fallback            | timestamp of latest       | 1.2.3b0.dev0+git.123.f1234567       |
-| post0, x.y.0 |                     |                     | commit + hash             |                                     |
-|              |                     |                     |                           |                                     |
-+--------------+---------------------+---------------------+---------------------------+-------------------------------------+
++--------------+---------------------+---------------------------+-------------------------------------+
+| Release type | ``kolibri.VERSION`` | Git data                  | Examples                            |
++==============+=====================+===========================+=====================================+
+| Final        | (1, 2, 3)           | Final tag: e.g. v1.2.3    | 1.2.3                               |
++--------------+---------------------+---------------------------+-------------------------------------+
+| dev release  | (1, 2, 3)           | timestamp of latest       | 1.2.3.dev0+git.123.f1234567         |
+| (alpha0)     |                     | commit + hash             |                                     |
++--------------+---------------------+---------------------------+-------------------------------------+
+| alpha1+      | (1, 2, 3)           | Alpha tag: e.g. v1.2.3a1  | Clean head:                         |
+|              |                     |                           | 1.2.3a1,                            |
+|              |                     |                           | 4 changes                           |
+|              |                     |                           | since tag:                          |
+|              |                     |                           | 1.2.3a1.dev0+git.4.f1234567         |
++--------------+---------------------+---------------------------+-------------------------------------+
+| beta1+       | (1, 2, 3)           | Beta tag: e.g. v1.2.3b1   | Clean head:                         |
+|              |                     |                           | 1.2.3b1,                            |
+|              |                     |                           | 5 changes                           |
+|              |                     |                           | since tag:                          |
+|              |                     |                           | 1.2.3b1.dev0+git.5.f1234567         |
++--------------+---------------------+---------------------------+-------------------------------------+
+| rc1+         | (1, 2, 3)           | RC tag: e.g. v1.2.3rc1    | Clean head:                         |
+| (release     |                     |                           | 1.2.3rc1,                           |
+| candidate)   |                     |                           | Changes                             |
+|              |                     |                           | since tag:                          |
+|              |                     |                           | 1.2.3rc1.dev0+git.f1234567          |
++--------------+---------------------+---------------------------+-------------------------------------+
 
 
-**Fallback**: ``kolibri/VERSION`` is auto-generated with ``make writeversion``
-during the build process. The file is read as a fallback when there's no git
-data available in a pre-release (which is the case in an installed
-environment).
+**Built assets**: ``kolibri/VERSION`` is auto-generated with ``make writeversion``
+during the build process. The file is read in preference to git
+data in order to prioritize swift version resolution in an installed
+environment.
 
 
 Release order example 1.2.3 release:
 
- * ``VERSION = (1, 2, 3, 'alpha', 0)`` throughout the development phase, this
+ * ``VERSION = (1, 2, 3)`` throughout the development phase, this
    results in a lot of ``1.2.3.dev0+git1234abcd`` with no need for
    git tags.
- * ``VERSION = (1, 2, 3, 'alpha', 1)`` for the first alpha release.
+ * ``VERSION = (1, 2, 3)`` for the first alpha release, a git tag v1.2.3a0 is made.
 
 .. warning::
     Do not import anything from the rest of Kolibri in this module, it's
@@ -117,41 +108,15 @@ PRERELEASE_VERSION = "prerelease"
 BUILD_VERSION = "build"
 
 
-def get_major_version(version=None):
+def get_major_version(version):
     """
     :returns: String w/ first digit part of version tuple x.y.z
     """
-    version = get_complete_version(version)
+
     major = ".".join(str(x) for x in version[:3])
     return major
 
 
-def get_complete_version(version=None):
-    """
-    :returns: A tuple of the version. If version argument is non-empty, then
-              checks for correctness of the tuple provided.
-    """
-    if version is None:
-        from kolibri import VERSION as version
-    else:
-        if len(version) != 5:
-            raise AssertionError
-        if version[3] not in ORDERED_VERSIONS:
-            raise AssertionError
-
-    return version
-
-
-def get_docs_version(version=None):
-    """
-    :returns: Version string for use in Sphinx docs
-    """
-    version = get_complete_version(version)
-    if version[3] != "final":
-        return "dev"
-    return "%d.%d" % version[:2]
-
-
 def get_git_changeset():
     """
     Returns a numeric identifier of the latest git changeset.
@@ -262,14 +227,12 @@ def get_version_from_git(get_git_describe_string):
     suffix = ".dev0+git" + suffix if suffix else ""
 
     return (
-        get_complete_version(
-            (
-                int(major),
-                int(minor),
-                int(patch),
-                m.group("release") or "final",
-                int(m.group("release_number") or 0),
-            )
+        (
+            int(major),
+            int(minor),
+            int(patch),
+            m.group("release") or "final",
+            int(m.group("release_number") or 0),
         ),
         suffix,
     )
@@ -294,31 +257,22 @@ def get_prerelease_version(version):
     \\*, \\*, \\*, "alpha", 0: Maps to latest commit timestamp
     \\*, \\*, \\*, "alpha", >0: Uses latest git tag, asserting that there is such.
     """
-
     mapping = {"alpha": "a", "beta": "b", "rc": "rc"}
-
     major = get_major_version(version)
-    major_and_release = major + mapping[version[3]] + str(version[4])
 
     # Calculate suffix...
     tag_describe = get_git_describe(version)
 
     # If the detected git describe data is not valid, then either respect
-    # that we are in alpha-0 mode or raise an error
+
     if tag_describe:
 
         git_version, suffix = get_version_from_git(tag_describe)
-
-        if not git_version[:3] == version[:3]:
-            # If it's the 0th alpha, load suffix info from git changeset
-            if version[4] == 0 and version[3] == "alpha":
-                # Throw away the description from git
-                suffix = get_git_changeset()
-                # Replace 'alpha' with .dev
-                return major + ".dev0" + suffix
-
-            # If the tag was not of a final version, we will fail.
-            elif not git_version[4] == "final" and git_version[:3] > version[:3]:
+        # We will check if the git_tag and version strings are the same length,
+        # and compare it the first three characters of each string to see if they matches.
+        # if not, we then raise an AssertionError.
+        if not suffix:
+            if not git_version[:3] == version[:3]:
                 raise AssertionError(
                     (
                         "Version detected from git describe --tags, but it's "
@@ -326,108 +280,80 @@ def get_prerelease_version(version):
                         "__version__ is: {}, tag says: {}."
                     ).format(str(version), git_version)
                 )
-
-        if git_version[3] == "final" and version[3] != "final":
+        # checks if the version number in git_version is greater than the version number in version.
+        # If it is, the code raises an AssertionError
+        if git_version[:3] > version[:3]:
             raise AssertionError(
-                "You have added a final tag without bumping kolibri.VERSION, "
-                + "OR you need to make a new alpha0 tag. Current tag: {}".format(
-                    git_version
-                )
-                + "\n\n"
-                "Often, this is because of missing tag information, try "
-                "running:\n"
-                "\n"
-                "   git fetch <upstream>"
+                (
+                    "Version detected from git describe --tags, but it's "
+                    "inconsistent with kolibri.__version__."
+                    "__version__ is: {}, tag says: {}."
+                ).format(str(version), git_version)
+            )
+        # checks if the tag in git_version is the same to the final version number in version.
+        # If it is, we return the major version number.
+        # And If the tag was of a final version, we will use it.
+
+        if git_version[:3] == version[:3]:
+            if git_version[3] == "final":
+                if not suffix:
+                    return major
+                else:
+                    # If there's a suffix, we're post the final tag for the release
+                    # so set it to an alpha to give a more meaningful version number
+                    # although it is slighly incorrect as we have already released.
+                    git_version = (
+                        git_version[0],
+                        git_version[1],
+                        git_version[2],
+                        "alpha",
+                        git_version[4],
+                    )
+
+            return (
+                get_major_version(git_version)
+                + mapping[git_version[3]]
+                + str(git_version[4])
+                + suffix
             )
 
-        return (
-            get_major_version(git_version)
-            + mapping[git_version[3]]
-            + str(git_version[4])
-            + suffix
-        )
+    return major + ".dev0" + (get_git_changeset() or "")
 
+
+def get_version_from_file(version):
     # No git data, will look for a VERSION file
     version_file = get_version_file()
 
     # Check that the version file is consistent
     if version_file:
-
         # Because \n may have been appended
         version_file = version_file.strip()
-
-        # If there is a '.dev', we can remove it, otherwise we check it
-        # for consistency and fail if inconsistent
-        version_file_base = parse_version(version_file).base_version
-
-        # If a final release is specified in the VERSION file, then it
-        # has to be a final release in the VERSION tuple as well.
-        # A final release specified in a VERSION file (pep 440) is
-        # something that doesn't end like a1, b1, post1, and rc1
-        pep440_is_final = re.compile(r"^\d+(\.\d)+(\.post\d+)?$")
-        version_file_is_final = pep440_is_final.match(version_file)
-
-        if version_file_is_final and version_file != major_and_release:
+        version_major_minor_patch = parse_version(version_file).base_version
+        split_version = version_major_minor_patch.split(".")
+        major = int(split_version[0])
+        minor = int(split_version[1])
+        patch = int(split_version[2])
+        # If the major, minor, and patch of the parsed version number
+        # We will raise an error
+        if (major, minor, patch) != version[:3]:
             raise AssertionError(
                 (
-                    "kolibri/VERSION file specified as final release but "
-                    "kolibri.__version__. is not a final release."
-                    "__version__ is: {}, file says: {}."
+                    "Version detected from VERSION file, but it's "
+                    "inconsistent with kolibri.__version__."
+                    "__version__ is: {}, VERSION file says: {}."
                 ).format(str(version), version_file)
             )
 
-        if not major_and_release.startswith(version_file_base):
-            raise AssertionError(
-                (
-                    "kolibri/VERSION file inconsistent with "
-                    "kolibri.__version__.\n"
-                    "__version__ is: {}, file says: {}\n\n{} should start "
-                    "with {}"
-                ).format(
-                    str(version), version_file, major_and_release, version_file_base
-                )
-            )
         return version_file
 
-    # Finally, if there was no git data or VERSION file, map the alpha-0 to
-    # .dev
-    if version[4] == 0 and version[3] == "alpha":
-        mapping["alpha"] = ".dev"
-        major_and_release = major + mapping[version[3]] + str(version[4])
-
-    # In all circumstances, return the initial findings
-    return major_and_release
-
 
 @lru_cache()
-def get_version(version=None):
-    """
-    Returns a PEP 440-compliant version number from VERSION.
-    Derives additional information from git repository if code is contained
-    in such.
+def get_version(version):
+    version_str = get_version_from_file(version)
+    if version_str:
+        return version_str
 
-    This is important to read from PEP-404 (which this function is compliant
-    with):
-
-    Within a numeric release ( 1.0.0 , 2.7.3 ), the following suffixes are
-    permitted and MUST be ordered as shown:
-
-    .devN, aN, bN, rcN, <no suffix>, .postN
-    """
-    version = get_complete_version(version)
-
-    # Prerelease versions are special, we parse git data and look for special
-    # VERSION files in package data to fetch auto-generated data.
-    if version[3] != "final":
-        return get_prerelease_version(version)
-
-    major = get_major_version(version)
-
-    sub = ""
-    if version[4] > 0:
-        sub = ".post{}".format(version[4])
-
-    return str(major + sub)
+    return get_prerelease_version(version)
 
 
 def get_version_and_operator_from_range(version_range):
@@ -472,6 +398,7 @@ def normalize_version_to_semver(version):
     dev = dev_match.group(2)
 
     # extract the numeric semver component and the stuff that comes after
+
     numeric, after = re.match(
         r"(^\d+\.\d+[0-9]*\.?[0-9]*)([a-z0-9.+]*)", version
     ).groups()
